@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.28 2002/02/11 12:10:30 mmclouglin Exp $
+ $Id: battstat_applet.c,v 1.38 2002/05/14 01:50:01 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -74,18 +74,6 @@ static const BonoboUIVerb battstat_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
-static const char battstat_menu_xml [] =
-	"<popup name=\"button3\">\n"
-	"   <menuitem name=\"Battstat Properties Item\" verb=\"BattstatProperties\" _label=\"Properties ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-properties\"/>\n"
-	"   <menuitem name=\"Battstat Help Item\" verb=\"BattstatHelp\" _label=\"Help\"\n"
-	"             pixtype=\"stock\" pixname=\"gtk-help\"/>\n"
-	"   <menuitem name=\"Battstat About Item\" verb=\"BattstatAbout\" _label=\"About ...\"\n"
-	"             pixtype=\"stock\" pixname=\"gnome-stock-about\"/>\n"
-	"   <menuitem name=\"Battstat Suspend Item\" verb=\"BattstatSuspend\" _label=\"Suspend Computer ...\"\n"
-	"             />\n"
-	"</popup>\n";
-
 int pixel_offset_top[]={ 5, 5, 6, 6, 6, 6, 6, 6, 6, 6, 5, 5 };
 int pixel_top_length[]={ 2, 3, 4, 4, 4, 4, 4, 4, 4, 4, 3, 2 };
 int pixel_offset_bottom[]={ 38, 38, 39, 39, 39, 39, 39, 39, 39, 39, 38, 38 };
@@ -295,8 +283,6 @@ apm_readinfo(void)
 	     on unsupported platform */
 	  _("Your platform is not supported!\n"));
   g_print(_("The applet will not work properly (if at all).\n"));
-
-  return;
 }
 #endif 
 
@@ -313,12 +299,6 @@ pixmap_timeout( gpointer data )
   ProgressData *battery = data;
 /*   MeterData *meter; */
   GdkColor *color, *darkcolor;
-  static guint flash=FALSE;
-  static guint last_batt_life=1000;
-  static guint last_acline_status=1000;
-  static guint last_batt_state=1000;
-  static guint last_pixmap_index=1000;
-  static guint last_charging=1000;
   guint batt_life;
   guint acline_status;
   guint batt_state;
@@ -396,29 +376,26 @@ pixmap_timeout( gpointer data )
   if(batt_life == 100) charging = FALSE;
   if(!acline_status) charging = FALSE;
  
-   flash = flash ? FALSE : TRUE;
+   battery->flash = battery->flash ? FALSE : TRUE;
 
    pixmap_index = (acline_status) ?
-              (charging && flash ? FLASH : AC) :
+              (charging && battery->flash ? FLASH : AC) :
               (batt_life <= battery->red_val ? WARNING : BATTERY)
    ;
 
-   if ( pixmap_index != last_pixmap_index ) {
-     printf ("foo\n");
+   if ( pixmap_index != battery->last_pixmap_index ) {
       gtk_pixmap_set(GTK_PIXMAP (battery->statuspixmapwid),
                      statusimage[pixmap_index], statusmask[pixmap_index]);
-     printf ("foo1\n");
 #ifdef FIXME
       gtk_pixmap_set(GTK_PIXMAP (battery->pixmapdockwid),
                      statusimage[pixmap_index], statusmask[pixmap_index]);
 #endif
-     printf ("foo2\n");
    }
 
    if(
      !acline_status
-     && last_batt_life != 1000
-     && last_batt_life > battery->red_val
+     && battery->last_batt_life != 1000
+     && battery->last_batt_life > battery->red_val
      && batt_life <= battery->red_val
    ) {
       /* Warn that battery dropped below red_val */
@@ -436,12 +413,13 @@ pixmap_timeout( gpointer data )
    }
 
    if(
-      last_charging
-      && last_acline_status
-      && last_acline_status!=1000
+      battery->last_charging
+      && battery->last_acline_status
+      && battery->last_acline_status!=1000
       && !charging 
       && acline_status
       && batterypresent
+      && batt_life > 99
    ) {
       /* Inform that battery now fully charged */
       gnome_triggers_do ("", NULL, "battstat_applet", "BatteryFull", NULL);
@@ -453,9 +431,9 @@ pixmap_timeout( gpointer data )
    }
 
    if(
-      acline_status != last_acline_status
-      || batt_life != last_batt_life
-      || batt_state != last_batt_state
+      acline_status != battery->last_acline_status
+      || batt_life != battery->last_batt_life
+      || batt_state != battery->last_batt_state
       || battery->colors_changed )
    {
       /* Something changed */
@@ -495,8 +473,8 @@ pixmap_timeout( gpointer data )
 	 snprintf(new_label, sizeof(new_label),_("N/A"));
       }
 
-      gtk_label_set_text ( GTK_LABEL (battery->percent), new_label);
-      gtk_label_set_text ( GTK_LABEL (battery->statuspercent), new_label);
+      gtk_label_set_text (GTK_LABEL (battery->percent), new_label);
+      gtk_label_set_text (GTK_LABEL (battery->statuspercent), new_label);
       
       if (batt_life <= battery->red_val) {
 	 color=red;
@@ -546,28 +524,6 @@ pixmap_timeout( gpointer data )
 				 i+2, pixel_offset_top[i]+progress_value);
 	       }
 	    }
-    
-	    if(battery->horizont) {
-	      GdkPixmap *pixmap;
-	      gtk_pixmap_get (GTK_PIXMAP (battery->pixmapwid), &pixmap, NULL);
-	      gdk_draw_pixmap(pixmap,
-			      battery->pixgc,
-			      battery->pixmap,
-			      0,0,
-			      0,2,
-			      -1,-1);
-	    }
-	    else {
-	      GdkPixmap *pixmap;
-	      gtk_pixmap_get (GTK_PIXMAP (battery->pixmapwidy), &pixmap, NULL);
-	      gdk_draw_pixmap(pixmap,
-			      battery->pixgc,
-			      battery->pixmapy,
-			      0,0,
-			      2,1,
-			      -1,-1);
-	    }
-
 	 } else {
 	    progress_value = PROGLEN*batt_life/100.0;
 	    
@@ -606,28 +562,29 @@ pixmap_timeout( gpointer data )
 				    i+2, x);
 	       }
 	    }
-    
-	    if(battery->horizont) {
-	      GdkPixmap *pixmap;
-	      gtk_pixmap_get (GTK_PIXMAP (battery->pixmapwid), &pixmap, NULL);
-	      gdk_draw_pixmap(pixmap,
-			      battery->pixgc,
-			      battery->pixmap,
-			      0,0,
-			      0,2,
-			      -1,-1);
-	    }
-	    else {
-	      GdkPixmap *pixmap;
-	      gtk_pixmap_get (GTK_PIXMAP (battery->pixmapwidy), &pixmap, NULL);
-	      gdk_draw_pixmap(pixmap,
-			      battery->pixgc,
-			      battery->pixmapy,
-			      0,0,
-			      2,1,
-			      -1,-1);
-	    }
+	 }
 
+	 if(battery->horizont) {
+	    GdkPixmap *pixmap;
+	    gtk_pixmap_get (GTK_PIXMAP (battery->pixmapwid), &pixmap, NULL);
+	    gdk_draw_pixmap(pixmap,
+			    battery->pixgc,
+			    battery->pixmap,
+			    0,0,
+			    0,0,
+			    -1,-1);
+	    gtk_widget_queue_draw (GTK_WIDGET (battery->pixmapwid));
+	 }
+	 else {
+	    GdkPixmap *pixmap;
+	    gtk_pixmap_get (GTK_PIXMAP (battery->pixmapwidy), &pixmap, NULL);
+	    gdk_draw_pixmap(pixmap,
+			    battery->pixgc,
+			    battery->pixmapy,
+			    0,0,
+			    0,0,
+			    -1,-1);
+	    gtk_widget_queue_draw (GTK_WIDGET (battery->pixmapwidy));
 	 }
       }
       
@@ -693,17 +650,18 @@ pixmap_timeout( gpointer data )
       if (DEBUG) printf("Percent: %d, Status: %s\n", batt_life, status[batt_state]);
    }
 
-   last_charging = charging;
-   last_batt_state = batt_state;
-   last_batt_life=batt_life;
-   last_acline_status = acline_status;
-   last_pixmap_index = pixmap_index;
+   battery->last_charging = charging;
+   battery->last_batt_state = batt_state;
+   battery->last_batt_life = batt_life;
+   battery->last_acline_status = acline_status;
+   battery->last_pixmap_index = pixmap_index;
 
-   return(TRUE);
+   
+   return TRUE;
 }
 
 void
-destroy_applet( GtkWidget *widget, gpointer data )
+destroy_applet (GtkWidget *widget, gpointer data)
 {
    ProgressData *pdata = data;
    
@@ -718,11 +676,30 @@ destroy_applet( GtkWidget *widget, gpointer data )
    gdk_bitmap_unref(pdata->mask);
    gdk_bitmap_unref(pdata->masky);
    gdk_bitmap_unref(pdata->pixmask);
-   g_free(pdata);
+
+   if (pdata->suspend_cmd)
+   	g_free (pdata->suspend_cmd);
    
+   g_free (pdata);
+
    return;
 }
 
+static void
+battstat_error_dialog(gchar *msg)
+{
+	GtkWidget *dialog;
+
+	dialog = gtk_message_dialog_new(NULL,
+			0,
+			GTK_MESSAGE_ERROR,
+			GTK_BUTTONS_OK,
+			msg);
+
+	gtk_dialog_run (GTK_DIALOG(dialog));
+	gtk_widget_destroy (dialog);
+}
+
 void
 cleanup(int status)
 {
@@ -730,7 +707,7 @@ cleanup(int status)
    
    switch (status) {
     case 1:
-      g_error (
+      battstat_error_dialog (
 	       /* Displayed if the APM device couldn't be opened. (Used under *BSD)*/
 	       _("Can't open the APM device!\n\n"
 		 "Make sure you have read permission to the\n"
@@ -738,7 +715,7 @@ cleanup(int status)
       exit(1);
       break;
     case 2:
-      g_error (
+      battstat_error_dialog (
 	       /* Displayed if the APM system is disabled (Used under *BSD)*/	     
 	       _("The APM Management subsystem seems to be disabled.\n"
 		 "Try executing \"apm -e 1\" (FreeBSD) and see if \n"
@@ -776,7 +753,30 @@ suspend_cb (PanelApplet *applet, gpointer data)
    ProgressData *battstat = data;
    
    if(battstat->suspend_cmd && strlen(battstat->suspend_cmd)>0) {
-      gnome_execute_shell(NULL, battstat->suspend_cmd);
+      GError *err = NULL;
+      gboolean ret;
+      gint shell_ret = 0;
+
+      ret = g_spawn_command_line_sync(battstat->suspend_cmd,
+		      NULL, NULL, &shell_ret, &err);
+      if (ret == FALSE || shell_ret != 0)
+      {
+	      gchar *msg;
+
+	      if (err != NULL)
+	      {
+		      msg = g_strdup_printf(_("An error occured while launching the Suspend command: %s\nPlease try to correct this error"), err->message);
+	      } else {
+		      /* Probably because the shell_ret is != 0 */
+		      msg = g_strdup_printf(_("An error occured while launching the Suspend command, the command returned \"%d\"\nPlease try to correct this error"), shell_ret);
+	      }
+	      battstat_error_dialog(msg);
+	      g_free(msg);
+	      if (err != NULL)
+		      g_error_free(err);
+      }
+   } else {
+      battstat_error_dialog(_("Suspend command wasn't setup correctly in the preferences.\nPlease change the preferences and try again."));
    }
    
    return;
@@ -798,25 +798,50 @@ void
 about_cb (PanelApplet *widget, gpointer data)
 {
    GtkWidget   *about_box;
-   char        *authors[] = { "Jrgen Pehrson <jp@spektr.eu.org>", 
-			      "Lennart Poettering <lennart@poettering.de> (Linux ACPI support)",
-			      "Seth Nickell <snickell@stanford.edu> (GNOME2 port)",
-			      NULL };
+   GdkPixbuf   *pixbuf;
+   GError      *error = NULL;
+   gchar       *file;
+   
+   const gchar *authors[] = {
+	/* if your charset supports it, please replace the "o" in
+	 * "Jorgen" into U00F6 */
+	_("Jorgen Pehrson <jp@spektr.eu.org>"), 
+	"Lennart Poettering <lennart@poettering.de> (Linux ACPI support)",
+	"Seth Nickell <snickell@stanford.edu> (GNOME2 port)",
+	NULL
+   };
+
+   const gchar *documenters[] = {
+	NULL
+   };
+
+   const gchar *translator_credits = _("translator_credits");
+   
+   file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "battstat.png", FALSE, NULL);
+   pixbuf = gdk_pixbuf_new_from_file (file, &error);
+   g_free (file);
+   
+   if (error) {
+   	g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+	g_error_free (error);
+   }
    
    about_box = gnome_about_new (
 				/* The long name of the applet in the About dialog.*/
-				_("Battery status utility"), 
+				_("Battery Charge Monitor"), 
 				VERSION,
 				_("(C) 2000 The Gnulix Society, (C) 2002 Free Software Foundation"),
 				_("This utility show the status of your laptop battery."),
-				(const char **) authors,
-				/* Longer description of the applet in the About dialog.*/
-				NULL,
-				NULL,
-				NULL);
-   /* FIXME
-				"battstat-tesla.xpm");
-   */
+				authors,
+				documenters,
+				strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+				pixbuf);
+   
+   if (pixbuf) 
+   	gdk_pixbuf_unref (pixbuf);
+   
+   gtk_window_set_wmclass (GTK_WINDOW (about_box), "battery charge monitor", "Batter Charge Monitor");
+   gnome_window_icon_set_from_file (GTK_WINDOW (about_box), GNOME_ICONDIR"/battstat.png");
    gtk_widget_show (about_box);
 }
 
@@ -839,7 +864,6 @@ change_orient (GtkWidget *w, PanelAppletOrient o, gpointer data)
       gettext_noop ("Critical"),
       /* Charging = The APM BIOS thinks that the battery is recharging.*/
       gettext_noop ("Charging")};
-   int width;
    battstat->orienttype=o;
    
    if (DEBUG) g_print("change_orient()\n");
@@ -1049,14 +1073,14 @@ font_set_cb (GtkWidget *ignored, int page, gpointer data)
 }
 
 void
-simul_cb(GtkWidget *ignored, gpointer data)
+simul_cb (GtkWidget *ignored, gpointer data)
 {
    ProgressData *battery = data;
    gchar new_label[40];
    GdkColor *color, *darkcolor;
    gint slidervalue;
    gint prefred, preforange, prefyellow, progress_value, i, x;
-   
+
    slidervalue=(int)GTK_ADJUSTMENT (battery->testadj)->value;
    prefyellow = (int) GTK_ADJUSTMENT (battery->eyellow_adj)->value;
    preforange =(int) GTK_ADJUSTMENT (battery->eorange_adj)->value;
@@ -1125,26 +1149,33 @@ simul_cb(GtkWidget *ignored, gpointer data)
 	 }
       }
    }
-   return;
+   gtk_widget_queue_draw (GTK_WIDGET (battery->testpixmapwid));
 }
 
 void
-adj_value_changed_cb ( GtkAdjustment *ignored, gpointer data )
+adj_value_changed_cb (GtkAdjustment *ignored, gpointer data)
 {
    ProgressData *battstat = data;
+   PanelApplet *applet = PANEL_APPLET (battstat->applet);
    
    GTK_ADJUSTMENT (battstat->ered_adj)->upper=(int)GTK_ADJUSTMENT (battstat->eorange_adj)->value-1;
    GTK_ADJUSTMENT (battstat->eorange_adj)->lower=(int)GTK_ADJUSTMENT (battstat->ered_adj)->value+1;
    GTK_ADJUSTMENT (battstat->eorange_adj)->upper=(int)GTK_ADJUSTMENT (battstat->eyellow_adj)->value-1;
    GTK_ADJUSTMENT (battstat->eyellow_adj)->lower=(int)GTK_ADJUSTMENT (battstat->eorange_adj)->value+1;
    
-   gnome_property_box_changed (GNOME_PROPERTY_BOX (battstat->prop_win));
-   
+   battstat->yellow_val = GTK_ADJUSTMENT (battstat->eyellow_adj)->value;
+   battstat->orange_val = GTK_ADJUSTMENT (battstat->eorange_adj)->value;
+   battstat->red_val = GTK_ADJUSTMENT (battstat->ered_adj)->value;
+   panel_applet_gconf_set_int (applet, "red_value", 
+   			       battstat->red_val, NULL);
+   panel_applet_gconf_set_int (applet, "orange_value",
+   			       battstat->orange_val,  NULL);
+   panel_applet_gconf_set_int (applet, "yellow_value", 
+   			       battstat->yellow_val, NULL);
    battstat->colors_changed = TRUE;
    simul_cb(NULL, battstat);
+   pixmap_timeout (battstat);
    battstat->colors_changed = FALSE;
-   
-   return;
 }
 
 #if 0
@@ -1174,8 +1205,6 @@ build_our_plug(StatusDocklet *docklet, GtkWidget *plug, gpointer data)
 			 battstat->eventdock,
 			 "Add code here",
 			 NULL);
-   
-   return;
 }
 #endif
 
@@ -1221,22 +1250,6 @@ load_preferences(ProgressData *battstat)
 
 }
 
-void
-save_preferences(ProgressData *battstat)
-{
-  PanelApplet *applet = PANEL_APPLET (battstat->applet);
-
-  panel_applet_gconf_set_int    (applet, GCONF_PATH "red_value", battstat->red_val, NULL);
-  panel_applet_gconf_set_int    (applet, GCONF_PATH "orange_value",battstat->orange_val,  NULL);
-  panel_applet_gconf_set_int    (applet, GCONF_PATH "yellow_value", battstat->yellow_val, NULL);
-  
-  
-  panel_applet_gconf_set_bool   (applet, GCONF_PATH "horizontal", battstat->horizont, NULL);
-
- 
-  panel_applet_gconf_set_bool   (applet, GCONF_PATH "use_dock", battstat->usedock, NULL);
-}
-
 gint
 create_layout(ProgressData *battstat)
 {
@@ -1439,9 +1452,15 @@ battstat_applet_fill (PanelApplet *applet)
   
   battstat->hbox1 = gtk_hbox_new (FALSE, 1);
   gtk_widget_show(battstat->hbox1);
-  
+
+  battstat->flash = FALSE;
+  battstat->last_batt_life = 1000;
+  battstat->last_acline_status = 1000;
+  battstat->last_batt_state = 1000;
+  battstat->last_pixmap_index = 1000;
+  battstat->last_charging = 1000;
   battstat->colors_changed = TRUE;
-  battstat->suspend_cmd = FALSE;
+  battstat->suspend_cmd = NULL;
   battstat->orienttype = panel_applet_get_orient (applet);
   battstat->panelsize = panel_applet_get_size (applet);
   
@@ -1457,8 +1476,12 @@ battstat_applet_fill (PanelApplet *applet)
 #endif  
   gtk_container_add (GTK_CONTAINER (battstat->applet), battstat->hbox1);
 
-  panel_applet_setup_menu (PANEL_APPLET (battstat->applet), 
-  			   battstat_menu_xml, battstat_menu_verbs, battstat);
+  panel_applet_setup_menu_from_file (PANEL_APPLET (battstat->applet), 
+  			             NULL,
+                                     "GNOME_BattstatApplet.xml",
+                                     NULL,
+                                     battstat_menu_verbs,
+                                     battstat);
 
   return TRUE;
 }
