@@ -61,6 +61,7 @@ static int cdplayer_timeout_callback(gpointer data);
 static void start_gtcd_cb(GtkWidget *w, gpointer data);
 static void properties_cb (GtkWidget *w, gpointer data);
 static void help_cb (GtkWidget *w, gpointer data);
+static void phelp_cb (GtkWidget *w, gpointer data);
 static void about_cb(GtkWidget *w, gpointer data);
 
 static void applet_change_size(GtkWidget *w, int size, gpointer data);
@@ -99,7 +100,7 @@ static const BonoboUIVerb applet_menu_verbs [] = {
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_CDPlayerApplet_Factory",
 			     PANEL_TYPE_APPLET,
-                             "CD-Player-Applet",
+                             "cdplayer",
                              "0",
                               applet_factory,
                               NULL)
@@ -152,7 +153,6 @@ applet_fill (PanelApplet *applet)
     gtk_tooltips_set_tip (tooltips, cd->panel.track_control.prev, _("Previous Track"), NULL);
     cd->panel.track_control.next = control_button_factory(next_xpm, G_CALLBACK(cdplayer_next), cd);
     gtk_tooltips_set_tip (tooltips, cd->panel.track_control.next, _("Next Track"), NULL);
-    led_init();
     led_create_widgets(&cd->panel.time, &cd->panel.track_control.display, (gpointer)cd);
 
     gtk_container_add (GTK_CONTAINER (applet), cdplayer);
@@ -227,7 +227,6 @@ cdplayer_destroy(GtkWidget * widget, gpointer data)
     g_free (cd->devpath);
     cd->devpath = NULL;
     g_free(cd);
-    led_done();
 }
 
 static void
@@ -265,8 +264,11 @@ start_gtcd_cb(GtkWidget *w, gpointer data)
 static void
 response_cb (GtkDialog *dialog, gint id, gpointer data)
 {
+    if(id == GTK_RESPONSE_HELP){
+         phelp_cb (dialog,data);
+	 return;
+    }
     gtk_widget_destroy (GTK_WIDGET (dialog));
-    
 }
 
 static void
@@ -347,6 +349,7 @@ properties_cb (GtkWidget *w, gpointer data)
     dialog = gtk_dialog_new_with_buttons(_("CD Player Preferences"),
                                          NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
                                          GTK_STOCK_CLOSE, GTK_RESPONSE_CLOSE,
+                                         GTK_STOCK_HELP, GTK_RESPONSE_HELP,
                                          NULL);
     gtk_dialog_set_default_response(GTK_DIALOG (dialog), GTK_RESPONSE_CLOSE);
     box = GTK_DIALOG(dialog)->vbox;
@@ -395,7 +398,16 @@ properties_cb (GtkWidget *w, gpointer data)
 static void
 help_cb (GtkWidget *w, gpointer data)
 {
+    GError *error = NULL;
 
+    gnome_help_display ("cdplayer", NULL, &error);
+    if (error) {
+        g_warning ("help error: %s\n", error->message);
+        g_error_free (error);
+        error = NULL;
+    }
+
+    return;
 }
 
 static void
@@ -896,3 +908,17 @@ set_atk_relation(GtkWidget *label, GtkWidget *widget)
     atk_relation_set_add(relation_set, relation);
     g_object_unref(G_OBJECT (relation));
 }
+
+static void
+phelp_cb (GtkWidget *w, gpointer data)
+{
+    GError *error = NULL;
+    gnome_help_display ("cdplayer", "cdplayer-usage", &error);
+    
+    if (error) {
+        g_warning ("help error: %s\n", error->message);
+        g_error_free (error);
+        error = NULL;
+    }
+    return;
+}
