@@ -196,8 +196,21 @@ timer_cb (EyesApplet *eyes_applet)
 static void
 about_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
-        static GtkWidget *about = NULL;
-        const gchar *authors [] = {N_("Dave Camp <campd@oit.edu>"), NULL};
+	static GtkWidget *about = NULL;
+	GdkPixbuf	 *pixbuf;
+	GError		 *error = NULL;
+	gchar		 *file;
+        
+        static const gchar *authors [] = {
+		"Dave Camp <campd@oit.edu>",
+		NULL
+	};
+
+	const gchar *documenters[] = {
+		NULL
+	};
+
+	const gchar *translator_credits = _("translator_credits");
 
 	if (about != NULL) {
 		gdk_window_show  (about->window);
@@ -205,14 +218,30 @@ about_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 		return;
 	}
         
+	file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gnome-eyes.png", FALSE, NULL);
+	pixbuf = gdk_pixbuf_new_from_file (file, &error);
+	g_free (file);
+	
+	if (error) {
+		g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+		g_error_free (error);
+	}
+	
         about = gnome_about_new (
-		_("gEyes"), VERSION,
+		_("Geyes"), VERSION,
 		_("Copyright (C) 1999 Dave Camp"),
 		_("A goofy little xeyes clone for the GNOME panel."),
 		authors,
-		NULL,
-		NULL,
-		NULL);
+		documenters,
+		strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+		pixbuf);
+		
+	if (pixbuf)
+		gdk_pixbuf_unref (pixbuf);
+			
+	gtk_window_set_wmclass (GTK_WINDOW (about), "geyes", "Geyes");
+	gnome_window_icon_set_from_file (GTK_WINDOW (about),
+					 GNOME_ICONDIR"/gnome-eyes.png");	
 	g_signal_connect (about, "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
 			  &about);
@@ -298,8 +327,10 @@ static void
 destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
 {
 	g_return_if_fail (eyes_applet);
-	
+
 	gtk_timeout_remove (eyes_applet->timeout_id);
+	if (eyes_applet->tooltips)
+		g_object_unref (eyes_applet->tooltips);
 	eyes_applet->timeout_id = 0;
 	if (eyes_applet->eye_image)
 		g_object_unref (eyes_applet->eye_image);
@@ -326,10 +357,8 @@ destroy_cb (GtkObject *object, EyesApplet *eyes_applet)
 static void
 help_cb (BonoboUIComponent *uic, gpointer user_data, const gchar *verbname)
 {
-#ifdef FIXME
-	static GnomeHelpMenuEntry help_entry = { "geyes_applet", "index.html"};
-	gnome_help_display(NULL, &help_entry);
-#endif
+	GError *error = NULL;
+	gnome_help_display("geyes",NULL,&error);
 }
 
 
@@ -341,6 +370,21 @@ static const BonoboUIVerb geyes_applet_menu_verbs [] = {
         BONOBO_UI_VERB_END
 };
 
+static void
+set_atk_name_description (GtkWidget *widget, const gchar *name,
+    const gchar *description)
+{
+	AtkObject *aobj;
+   
+	aobj = gtk_widget_get_accessible (widget);
+	/* Check if gail is loaded */
+	if (GTK_IS_ACCESSIBLE (aobj) == FALSE)
+		return;
+
+	atk_object_set_name (aobj, name);
+	atk_object_set_description (aobj, description);
+}
+
 static gboolean
 geyes_applet_fill (PanelApplet *applet)
 {
@@ -359,7 +403,15 @@ geyes_applet_fill (PanelApplet *applet)
                                            NULL,
 				           geyes_applet_menu_verbs,
 				           eyes_applet);
-	
+
+	eyes_applet->tooltips = gtk_tooltips_new ();
+	g_object_ref (eyes_applet->tooltips);
+	gtk_object_sink (GTK_OBJECT (eyes_applet->tooltips));
+	gtk_tooltips_set_tip (eyes_applet->tooltips, GTK_WIDGET (eyes_applet->applet), _("Geyes"), NULL);
+
+	set_atk_name_description (GTK_WIDGET (eyes_applet->applet), _("Geyes"), 
+			_("The eyes look in the direction of the mouse pointer"));
+
 	gtk_widget_show_all (GTK_WIDGET (eyes_applet->applet));
 
 	g_signal_connect (eyes_applet->applet,
@@ -390,7 +442,7 @@ geyes_applet_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_GeyesApplet_Factory",
 			     PANEL_TYPE_APPLET,
-			     "Geyes Applet",
+			     "geyes",
 			     "0",
 			     geyes_applet_factory,
 			     NULL)
