@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.46 2002/05/01 21:01:10 kevinv Exp $ */
+/* $Id: gweather-applet.c,v 1.47 2002/05/14 20:52:07 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -114,6 +114,12 @@ static void help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbnam
 {
     GError *error = NULL;
     gnome_help_display("gweather",NULL,&error);
+ 
+    if (error) {
+        g_warning ("help error: %s\n", error->message);
+        g_error_free (error);
+        error = NULL;
+    }
 }
 
 static void pref_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
