@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.10 2002/02/11 12:10:37 mmclouglin Exp $ */
+/* $Id: main.c,v 1.11 2002/05/01 21:01:10 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -10,9 +10,7 @@
  *
  */
 
-#ifdef HAVE_CONFIG_H
 #  include <config.h>
-#endif
 
 #include <gnome.h>
 #include <panel-applet.h>
@@ -58,7 +56,7 @@ gweather_applet_factory(PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY("OAFIID:GNOME_GWeatherApplet_Factory",
 			PANEL_TYPE_APPLET,
-			"GWeather Applet Factory",
+			"gweather",
 			"0",
 			gweather_applet_factory,
 			NULL);
