@@ -61,9 +61,7 @@ applet_destroy_signal(GtkWidget *widget, gpointer data)
         g_object_set_data (G_OBJECT (applet), "tooltips", NULL);
     }
     
-    /* applet will be destroyed; save history */
-    save_session();
-
+    
 #if 0 /* Freeing these prevents the applet from restarting - not sure what's up */
   
     g_free (mcdata->prop);
@@ -311,6 +309,8 @@ redraw_applet(MCData *mcdata)
         _("Click this button for the list of previous commands"));
     set_atk_name_description(GTK_WIDGET(applet), _("Mini-Commander applet"),
         _("This applet adds a command line to the panel"));
+    
+    gtk_tooltips_set_tip (tooltips, GTK_WIDGET (applet),  _("Command Line"), NULL);
 	
     /* add buttons into frame */
     frame = gtk_frame_new(NULL);
@@ -354,8 +354,6 @@ redraw_applet(MCData *mcdata)
 		    gtk_container_add(GTK_CONTAINER(frame2), handle);
 		}
 	    
-	    gtk_tooltips_set_tip (tooltips, GTK_WIDGET (applet),  _("Command Line"), NULL);
-	    
 	    if (prop->show_frame)
 		gtk_box_pack_start(GTK_BOX(mcdata->applet_inner_vbox), frame2, TRUE, TRUE, 0);
 	    else
@@ -463,7 +461,7 @@ mini_commander_applet_factory(PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_MiniCommanderApplet_Factory",
 			     PANEL_TYPE_APPLET,
-                             "Mini-Commander",
+                             "command-line",
                              "0",
                              mini_commander_applet_factory,
                              NULL)
